% INITIALIZATION SCRIPT FOR YEAST AND ARABIDOPSIS THALIANA
%
% This script loads all the datasets required for running the experiment
% selection algorithm. Please set "PAPER_CODE" as the default directory
% before running this script and place the following files in the 
% "DATA" sub-directory of "PAPER_CODE":
% arrayData: A compendium of microarray datasets in matrix form where every 
% row represents a gene and every column is an experimental condition. The
% matrix should not contain any missing values.
% arrayInd: This is an index file containing identifiers for each
% experiment in the compendium.
% arrayGenes: This contains the list of gene identifiers for the data in
% arrayData.
% Annot: the file containing the gene annotation, can be downloaded
% from http://www.geneontology.org/GO.downloads.annotations.shtml
% GO: The gene ontology file in OBO format
%
% Prajwal Bhat, July 27, 2011
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all; close all; clc;
org=input('Which organism do you want to work on? [1 = ARABIDOPSIS, 2 = YEAST]: ','s');
fprintf('Please wait while the system is initialized. this might take a few minutes... \n');
%input = 1; 
switch(str2num(org))
    case(1)
        disp('Getting data...')
        
        global arrayData; %data matrix containing the microarray compendium
        arrayData = importdata('../../DATA/ARABIDOPSIS_DATA/ATGE_data_Mod.txt');
                
        global arrayInd; %index file to identify experiments
        arrayInd = importdata('../../DATA/ARABIDOPSIS_DATA/ATGE_exp_indices_Mod.txt');
        
        global arrayGenes; %file containing gene identifiers
        arrayGenes = importdata('../../DATA/ARABIDOPSIS_DATA/ATGE_genelist.txt');
        arrayGenes = lower(arrayGenes);
        
        global Annot; %annotation file for the selected organism
        Annot = goannotread('../../DATA/ARABIDOPSIS_DATA/gene_association.tair');  % loading Arabidopsis annotation file
        
        global GO; %load GO tree file
        GO = geneont('File','../../DATA/ARABIDOPSIS_DATA/GOobject'); 
        
        global alldata;
        
        global maxExp;
        maxExp = size(unique(arrayInd),1); %count the total number of 
        % experiments available in the compendium
    
    case(2)
        disp('Getting data...')
        
        global arrayData; %data matrix containing the microarray compendium
        arrayData = importdata('//home/paccanaro/praj/Gene_corr_paper_yeast/Data/m3dyeast201010/m3ddata201010.txt'); 
        
        global arrayInd; %index file to identify experiments
        arrayInd = importdata('/home/paccanaro/praj/Gene_corr_paper_yeast/Data/m3dyeast201010/m3dexpIndex201010.txt'); 
        
        global arrayGenes; %file containing gene identifiers
        arrayGenes =  importdata('/home/paccanaro/praj/Gene_corr_paper_yeast/Data/m3dyeast201010/m3dgenes201010.txt');
        arrayGenes = lower(arrayGenes);
        
        global Annot; %annotation file for the selected organism
        Annot = goannotread('/rmt/csnewton/paccanarohome/praj/Gene_corr_paper_yeast/Data/gene_association.sgd');  
        
        global GO; %load GO tree file
        GO = geneont('File','/rmt/csnewton/paccanarohome/praj/Gene_corr_paper_yeast/Data/GOobject'); 
        
        global expLabels;
        expLabels =   importdata('/home/paccanaro/praj/Gene_corr_paper_yeast/Data/m3dyeast201010/m3dexpList.txt');
        
        global alldata;
        
        global maxExp
        
        maxExp = 31;
end
fprintf('INITIALIZATION COMPLETED \n');
